@@ -27,11 +27,11 @@ class DifferentiateAssistant : public Cantor::Assistant
 {
   public:
     DifferentiateAssistant( QObject* parent, QList<QVariant> args );
-    ~DifferentiateAssistant() override;
+    ~DifferentiateAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
     
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
     
 };
 
