@@ -23,10 +23,10 @@
 #include <QAction>
 #include <QIcon>
 
-#include <KDialog>
+#include <QDialog>
 #include <KActionCollection>
 #include <QFileDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <QUrl>
 #include "cantor_macros.h"
 #include "backend.h"
@@ -37,11 +37,6 @@ RunScriptAssistant::RunScriptAssistant(QObject* parent, QList<QVariant> args) :
     Q_UNUSED(args)
 }
 
-RunScriptAssistant::~RunScriptAssistant()
-{
-
-}
-
 void RunScriptAssistant::initActions()
 {
     setXMLFile(QLatin1String("cantor_runscript_assistant.rc"));
@@ -67,5 +62,5 @@ QStringList RunScriptAssistant::run(QWidget* parent)
     }
 }
 
-K_EXPORT_CANTOR_PLUGIN(runscriptassistant, RunScriptAssistant)
+K_PLUGIN_FACTORY_WITH_JSON(runscriptassistant, "runscriptassistant.json", registerPlugin<RunScriptAssistant>();)
 #include "runscriptassistant.moc"
