@@ -22,6 +22,7 @@
 #define _PYTHONCOMPLETIONOBJECT_H
 
 #include "completionobject.h"
+#include "expression.h"
 
 class PythonSession;
 
@@ -29,15 +30,20 @@ class PythonCompletionObject : public Cantor::CompletionObject
 {
   public:
     PythonCompletionObject(const QString& cmd, int index, PythonSession* session);
-    ~PythonCompletionObject() override;
+    ~PythonCompletionObject() override = default;
 
   protected:
-    bool mayIdentifierContain(QChar c) const Q_DECL_OVERRIDE;
-    bool mayIdentifierBeginWith(QChar c) const Q_DECL_OVERRIDE;
+    bool mayIdentifierContain(QChar c) const override;
+    bool mayIdentifierBeginWith(QChar c) const override;
 
   protected Q_SLOTS:
-    void fetchCompletions() Q_DECL_OVERRIDE;
-    void fetchIdentifierType() Q_DECL_OVERRIDE;
+    void fetchCompletions() override;
+    void fetchIdentifierType() override;
+    void extractCompletions(Cantor::Expression::Status status);
+    void extractIdentifierType(Cantor::Expression::Status status);
+
+  private:
+    Cantor::Expression* m_expression;
 };
 
 #endif /* _PYTHONCOMPLETIONOBJECT_H */
