@@ -29,13 +29,14 @@ class Python2Backend : public PythonBackend
   public:
     explicit Python2Backend(QObject* parent = nullptr, const QList<QVariant> args = QList<QVariant>());
 
-    Cantor::Session* createSession();
+    Cantor::Session* createSession() override;
 
-    QString id() const;
-    QUrl helpUrl() const;
-    QString description() const;
+    QString id() const override;
+    QString version() const override;
+    QUrl helpUrl() const override;
+    QString description() const override;
 
-    KConfigSkeleton* config() const;
+    KConfigSkeleton* config() const override;
 };
 
 #endif
