@@ -52,10 +52,9 @@
 #include <QApplication>
 #include <QStack>
 
-QalculateExpression::QalculateExpression( QalculateSession* session )
-    : Cantor::Expression(session)
+QalculateExpression::QalculateExpression( QalculateSession* session, bool internal)
+    : Cantor::Expression(session, internal), m_tempFile(nullptr)
 {
-    m_tempFile = 0;
 }
 
 QalculateExpression::~QalculateExpression()
@@ -751,6 +750,7 @@ ParseOptions QalculateExpression::parseOptions()
     }
 
     po.base = QalculateSettings::base();
+    po.comma_as_separator = false;
 
     return po;
 }
