@@ -31,18 +31,19 @@ using namespace Cantor;
 #include "latexresult.h"
 #include "settings.h"
 
+#include <QDebug>
 #include <QFileInfo>
 #include <QString>
+#include <QFileSystemWatcher>
 
 #include <KProcess>
-#include <QDebug>
 #include <KZip>
 
 class Cantor::ExpressionPrivate
 {
 public:
-    ExpressionPrivate() : result(nullptr), status(Expression::Done), session(nullptr),
-    finishingBehavior(Expression::DoNotDelete), isInternal(false)
+    ExpressionPrivate() : id(-1), status(Expression::Done), session(nullptr),
+    finishingBehavior(Expression::DoNotDelete), internal(false), fileWatcher(nullptr)
     {
     }
 
@@ -50,11 +51,12 @@ public:
     QString command;
     QString error;
     QList<QString> information;
-    Result* result;
+    QVector<Result*> results;
     Expression::Status status;
     Session* session;
     Expression::FinishingBehavior finishingBehavior;
-    bool isInternal;
+    bool internal;
+    QFileSystemWatcher* fileWatcher;
 };
 
 static const QString tex=QLatin1String("\\documentclass[12pt,fleqn]{article}          \n "\
@@ -69,16 +71,30 @@ static const QString tex=QLatin1String("\\documentclass[12pt,fleqn]{article}
                          "\\end{document}\n");
 
 
-Expression::Expression( Session* session ) : QObject( session ),
+Expression::Expression( Session* session, bool internal ) : QObject( session ),
                                              d(new ExpressionPrivate)
 {
     d->session=session;
-    d->id=session->nextExpressionId();
+    d->internal = internal;
+    if (!internal && session)
+        d->id=session->nextExpressionId();
+    else
+        d->id = -1;
+}
+
+Expression::Expression( Session* session, bool internal, int id ) : QObject( session ), d(new ExpressionPrivate)
+{
+    d->session = session;
+    d->internal = internal;
+    d->id = id;
 }
 
 Expression::~Expression()
 {
-    delete d->result;
+    qDeleteAll(d->results);
+    if (d->fileWatcher)
+        delete d->fileWatcher;
+
     delete d;
 }
 
@@ -103,13 +119,20 @@ QString Expression::errorMessage()
 }
 
 void Expression::setResult(Result* result)
+{
+    clearResults();
+    addResult(result);
+}
+
+void Expression::addResult(Result* result)
 {
     if(result!=nullptr)
     {
-        qDebug()<<"settting result to a type "<<result->type()<<" result";
+        qDebug()<<"setting result to a type "<<result->type()<<" result";
         #ifdef WITH_EPS
         //If it's text, and latex typesetting is enabled, render it
-        if ( session()->isTypesettingEnabled()&&
+        if ( session() &&
+             session()->isTypesettingEnabled()&&
              result->type()==TextResult::Type &&
              dynamic_cast<TextResult*>(result)->format()==TextResult::LatexFormat &&
              !result->toHtml().trimmed().isEmpty() &&
@@ -123,25 +146,45 @@ void Expression::setResult(Result* result)
         #endif
     }
 
-    if(d->result)
-        delete d->result;
-
-    d->result=result;
-
+    d->results << result;
     emit gotResult();
 }
 
+void Expression::clearResults()
+{
+    qDeleteAll(d->results);
+    d->results.clear();
+    emit resultsCleared();
+}
+
+void Expression::removeResult(Result* result)
+{
+    int index = d->results.indexOf(result);
+    d->results.remove(index);
+    delete result;
+    emit resultRemoved(index);
+}
+
+void Expression::replaceResult(int index, Result* result)
+{
+    if (result)
+    {
+        d->results.insert(index, result);
+        emit resultReplaced(index);
+    }
+}
+
 Result* Expression::result()
 {
-    return d->result;
+    if (!d->results.isEmpty())
+        return d->results.first();
+    else
+        return nullptr;
 }
 
-void Expression::clearResult()
+const QVector<Result*>& Expression::results() const
 {
-    if(d->result)
-        delete d->result;
-
-    d->result=nullptr;
+    return d->results;
 }
 
 void Expression::setStatus(Expression::Status status)
@@ -164,9 +207,6 @@ Session* Expression::session()
 }
 void Expression::renderResultAsLatex(Result* result)
 {
-    qDebug()<<"rendering as latex";
-    qDebug()<<"checking if it really is a formula that can be typeset";
-
     LatexRenderer* renderer=new LatexRenderer(this);
     renderer->setLatexCode(result->data().toString().trimmed());
     renderer->addHeader(additionalLatexHeaders());
@@ -188,20 +228,20 @@ void Expression::latexRendered(LatexRenderer* renderer, Result* result)
         {
             TextResult* r=dynamic_cast<TextResult*>(result);
             LatexResult* latex=new LatexResult(r->data().toString().trimmed(), QUrl::fromLocalFile(renderer->imagePath()), r->plain());
-            setResult( latex );
+            addResult( latex );
         }
         else if (result->type() == LatexResult::Type)
         {
             LatexResult* previousLatexResult=dynamic_cast<LatexResult*>(result);
             LatexResult* latex=new LatexResult(previousLatexResult->data().toString().trimmed(), QUrl::fromLocalFile(renderer->imagePath()), previousLatexResult->plain());
-            setResult( latex );
+            addResult( latex );
         }
     }else
     {
         //if rendering with latex was not successful, just use the plain text version
         //if available
         TextResult* r=dynamic_cast<TextResult*>(result);
-        setResult(new TextResult(r->plain()));
+        addResult(new TextResult(r->plain()));
         qDebug()<<"error rendering latex: "<<renderer->errorMessage();
     }
 
@@ -210,31 +250,6 @@ void Expression::latexRendered(LatexRenderer* renderer, Result* result)
     renderer->deleteLater();
 }
 
-//saving code
-QDomElement Expression::toXml(QDomDocument& doc)
-{
-    QDomElement expr=doc.createElement( QLatin1String("Expression") );
-    QDomElement cmd=doc.createElement( QLatin1String("Command") );
-    QDomText cmdText=doc.createTextNode( command() );
-    cmd.appendChild( cmdText );
-    expr.appendChild( cmd );
-    if ( result() )
-    {
-        qDebug()<<"result: "<<result();
-        QDomElement resXml=result()->toXml( doc );
-        expr.appendChild( resXml );
-    }
-
-    return expr;
-}
-
-void Expression::saveAdditionalData(KZip* archive)
-{
-    //just pass this call to the result
-    if(result())
-        result()->saveAdditionalData(archive);
-}
-
 void Expression::addInformation(const QString& information)
 {
     d->information.append(information);
@@ -245,6 +260,13 @@ QString Expression::additionalLatexHeaders()
     return QString();
 }
 
+QFileSystemWatcher* Expression::fileWatcher() {
+    if (!d->fileWatcher)
+        d->fileWatcher = new QFileSystemWatcher();
+
+    return d->fileWatcher;
+}
+
 int Expression::id()
 {
     return d->id;
@@ -266,15 +288,7 @@ Expression::FinishingBehavior Expression::finishingBehavior()
     return d->finishingBehavior;
 }
 
-void Expression::setInternal(bool internal)
-{
-    d->isInternal=internal;
-}
-
 bool Expression::isInternal()
 {
-    return d->isInternal;
+    return d->internal;
 }
-
-
-
