@@ -35,15 +35,16 @@
 
 #include "ui_newvardlg.h"
 
-VariableManagerWidget::VariableManagerWidget(Cantor::Session* session, QWidget* parent) : QWidget(parent), m_session(nullptr)
+VariableManagerWidget::VariableManagerWidget(Cantor::Session* session, QWidget* parent) : QWidget(parent),
+m_session(nullptr),
+m_model(nullptr),
+m_table(new QTreeView(this))
 {
     QVBoxLayout* layout=new QVBoxLayout(this);
-
-    m_table=new QTreeView(this);
-    m_table->setRootIsDecorated(false);
-
     layout->addWidget(m_table, 1);
 
+    m_table->setRootIsDecorated(false);
+
     QHBoxLayout* btnLayout=new QHBoxLayout();
     int size=KIconLoader::global()->currentSize(KIconLoader::MainToolbar);
 
@@ -92,11 +93,6 @@ VariableManagerWidget::VariableManagerWidget(Cantor::Session* session, QWidget*
         m_clearBtn->setDisabled(true);
 }
 
-VariableManagerWidget::~VariableManagerWidget()
-{
-
-}
-
 void VariableManagerWidget::setSession(Cantor::Session* session)
 {
     m_session=session;
